Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: src/bootstrapper.cc

Issue 11190050: Heavy cleanup of the external pointer API. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/bootstrapper.cc
diff --git a/src/bootstrapper.cc b/src/bootstrapper.cc
index a368eefe766985547d2e2f8cbe37a07dff4418dd..0fac90deac82cccccfdcca698a53cb4ede1ab508 100644
--- a/src/bootstrapper.cc
+++ b/src/bootstrapper.cc
@@ -1240,8 +1240,8 @@ bool Genesis::InitializeGlobal(Handle<GlobalObject> inner_global,
// Initialize the out of memory slot.
native_context()->set_out_of_memory(heap->false_value());
- // Initialize the data slot.
- native_context()->set_data(heap->undefined_value());
+ // Initialize the embedder data slot.
+ native_context()->set_embedder_data(*factory->NewFixedArray(2));
Michael Starzinger 2012/10/25 09:41:53 This pattern is not GC-safe and GCMole will (hopef
Sven Panne 2012/10/25 14:23:08 Done.
{
// Initialize the random seed slot.

Powered by Google App Engine
This is Rietveld 408576698